#
# spec file for package jackson-dataformats-binary
#
# Copyright (c) 2019 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with extra_dataformats
# Extra formats are disabled because of circular dependencies
Name:           jackson-dataformats-binary
Version:        2.10.1
Release:        lp152.1.37
Summary:        Jackson standard binary data format backends
License:        Apache-2.0 AND BSD-3-Clause
Group:          Development/Libraries/Java
URL:            https://github.com/FasterXML/jackson-dataformats-binary
Source0:        https://github.com/FasterXML/jackson-dataformats-binary/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-annotations) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:) >= %{version}
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildArch:      noarch
%if %{with extra_dataformats}
BuildRequires:  mvn(ch.qos.logback:logback-classic)
BuildRequires:  mvn(com.squareup:protoparser)
BuildRequires:  mvn(org.apache.avro:avro)
BuildRequires:  mvn(org.assertj:assertj-core)
%endif

%description
Parent pom for Jackson binary dataformats.

%if %{with extra_dataformats}
%package -n jackson-dataformat-avro
Summary:        Support for reading and writing AVRO-encoded data via Jackson abstractions
Group:          Development/Libraries/Java

%description -n jackson-dataformat-avro
Jackson extension component for reading and writing data encoded using Apache
Avro data format. Project adds necessary abstractions on top to make things
work with other Jackson functionality. It relies on standard Avro library for
Avro Schema handling, and some parts of deserialization/serialization.

%package -n jackson-dataformat-protobuf
Summary:        Support for reading and writing protobuf-encoded data via Jackson abstractions
Group:          Development/Libraries/Java

%description -n jackson-dataformat-protobuf
Jackson extension component for reading and writing Protobuf encoded data
(see protobuf encoding spec). This project adds necessary abstractions on top
to make things work with other Jackson functionality; mostly just low-level
Streaming components (JsonFactory, JsonParser, JsonGenerator).
%endif

%package -n jackson-dataformat-cbor
Summary:        Support for reading and writing Concise Binary Object Representation
Group:          Development/Libraries/Java

%description -n jackson-dataformat-cbor
Jackson data format module that supports reading and writing CBOR ("Concise
Binary Object Representation") encoded data. Module extends standard Jackson
streaming API (JsonFactory, JsonParser, JsonGenerator), and as such works
seamlessly with all the higher level data abstractions (data binding, tree
model, and pluggable extensions).

%package -n jackson-dataformat-smile
Summary:        Support for reading and writing Smile encoded data using Jackson abstractions
Group:          Development/Libraries/Java

%description -n jackson-dataformat-smile
This Jackson extension handles reading and writing of data encoded in Smile
data format ("binary JSON"). It extends standard Jackson streaming API
(JsonFactory, JsonParser, JsonGenerator), and as such works seamlessly with
all the higher level data abstractions (data binding, tree model, and
pluggable extensions).

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

cp -p ion/LICENSE .
cp -p ion/NOTICE .
sed -i 's/\r//' LICENSE NOTICE

%if %{without extra_dataformats}
%pom_disable_module avro
%pom_disable_module protobuf
%endif

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin org.moditect:moditect-maven-plugin cbor
%pom_remove_plugin org.moditect:moditect-maven-plugin smile

# Deps are not available in packages for this module
%pom_disable_module ion

%{mvn_file} ":{*}" jackson-dataformats/@1

%build
%{mvn_build} -s -f

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles-jackson-dataformats-binary
%doc README.md release-notes/*
%license LICENSE NOTICE

%if %{with extra_dataformats}
%files -n jackson-dataformat-avro -f .mfiles-jackson-dataformat-avro
%doc avro/README.md avro/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-protobuf -f .mfiles-jackson-dataformat-protobuf
%doc protobuf/README.md protobuf/release-notes/*
%license LICENSE NOTICE
%endif

%files -n jackson-dataformat-cbor -f .mfiles-jackson-dataformat-cbor
%doc cbor/README.md cbor/release-notes/*
%license LICENSE NOTICE

%files -n jackson-dataformat-smile -f .mfiles-jackson-dataformat-smile
%doc smile/README.md smile/release-notes/*
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Wed Nov 20 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Remove plugins unnecessary for RPM builds org.moditect:moditect-maven-plugin
* Wed Nov 20 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Version update to 2.10.1
  * 2.10.1 (09-Nov-2019)
    [#185]: Internal parsing of tagged arrays can lead to stack overflow
    [#188]: Unexpected `MismatchedInputException` for `byte[]` value bound to `String`
    in collection/array (actual fix in `jackson-databind`)
  * 2.10.0 (26-Sep-2019)
    [#139]: (cbor) Incorrect decimal fraction representation
    [#148]: (protobuf) Add `ProtobufMapper.generateSchemaFor(TypeReference<?>)` overload
    [#155]: (cbor, smile) Inconsistent support for FLUSH_PASSED_TO_STREAM
    [#157]: (all) Add simple module-info for JDK9+, using Moditect
    [#163]: (ion) Update `ion-java` dependency
    [#168]: (avro) `JsonMappingException` for union types with multiple Record types
    [#173]: (avro) Improve Union type serialization performance
    [#177]: (avro) Deserialization of "empty" Records as root values fails
    [#178]: (cbor) Fix issue wit input offsets when parsing CBOR from `InputStream`
    [#180]: (protobuf) Add `ProtobufGenerator.canWriteBinaryNatively()` to support binary writes
  - asm version upgrade to 6.2.1 (from 5.1)
  - (cbor, smile) Rewrote handling of "output context" for better field id write support
  * 2.9.10 (21-Sep-2019)
    No changes since 2.9.9
  * 2.9.9 (16-May-2019)
    [#159]: (cbor) Some short UTF Strings encoded using non-canonical form
    [#161]: (avro) Deserialize from newer version to older one throws NullPointerException
  * 2.9.8 (15-Dec-2018)
    [#140]: (protobuf) Stack overflow when generating Protobuf schema  on class with
    cyclic type definition
    [#153]: (smile) Unable to set a compression input/output decorator to a `SmileFactory`
  * 2.9.7 (19-Sep-2018)
    [#142]: (ion) `IonParser.getNumberType()` returns `null` for `IonType.FLOAT`
    [#150]: Add `CBORMapper`
    [#151]: Add `SmileMapper`
  * 2.9.6 (12-Jun-2018)
    [#93]: (cbor) `CBORParser` does not accept "undefined value"
    [#135]: (protobuf) Infinite sequence of `END_OBJECT` tokens returned at end of streaming read
    [#136]: (avro) Fix MapWriteContext not correctly resolving union values
  * 2.9.5 (26-Feb-2018)
    [#128] (protobuf) Fix skip unknown WireType.FIXED_64BIT value bug
    [#129] (cbor) Remove "final" modifier from `CBORParser`
* Tue Nov 12 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of jackson-dataformats-binary 2.9.4
